.. Prophet documentation master file, created by
   sphinx-quickstart on Wed Nov 19 05:52:00 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Prophet
==================

Prophet is a Python microframework for financial markets. Prophet strives to let the programmer focus on modeling financial strategies, portfolio management, and analyzing backtests. It achieves this by having few functions to learn to hit the ground running, yet being flexible enough to accomodate sophistication.

Go to :ref:`quickstart` to get started or see the :ref:`tutorial` for a more thorough introduction.

Prophet's data generators, order generators, and analyzers are all executed sequentially which is conducive to allowing individuals to build off of others work. If you have a package you would like to share, please open an issue on the github repository to register it in the :ref:`registry`.

Features
--------

- Flexible market backtester
- Convenient order generator
- See :ref:`roadmap` for upcoming features


User Guide
----------

.. toctree::
   :maxdepth: 2

   quickstart
   tutorial
   advanced
   best_practices
   registry


API Reference
-------------

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api


Contributor Guide
-----------------

.. toctree::
   :maxdepth: 2

   contributors


Additional Notes
----------------

.. toctree::
   :maxdepth: 1

   roadmap
   changelog
   license
